==> pollinations.ai-0.1.0.tar.gz: pollinations.ai-0.1.0/setup.py <==
from setuptools import setup, find_packages
from pathlib import Path

path_absolute = Path(__file__).parent.absolute()

with open(f'{path_absolute}/pollinations/__init__.py', 'r') as file:
  for line in file.readlines():
    if line.startswith('__version__'):
      version = line.split('=')[1].strip()[1:-1]
      break

setup(
    name="pollinations.ai",
    version=version,
    description="pollinations.ai | Image Generation",
    long_description=Path(f"{path_absolute}/README.md").read_text(encoding="utf-8"),
    long_description_content_type="text/markdown",
    url="https://pollinations.ai/",
    author="pollinations.ai",
    author_email="hello@pollinations.ai",
    license="MIT",
    classifiers=[
      "License :: OSI Approved :: MIT License",
      'Development Status :: 1 - Planning',
      'Intended Audience :: Developers',
      'License :: OSI Approved :: MIT License',
      'Programming Language :: Python',
      'Topic :: Software Development :: Libraries :: Python Modules',
      'Topic :: Utilities',
      'Typing :: Typed'
    ],
    packages=find_packages(exclude=("tests",)),
    include_package_data=True,
    entry_points={
        "console_scripts": [
            "pollinations=pollinations.__init__:main",
        ]
    },
    python_requires=">=3.7",    
    keywords=['pollinations', 'pollinations.ai', 'pollinations-ai', 'pollinations_ai'],
    project_urls={
      'website': 'https://pollinations.ai/',
      'discord': 'https://discord.gg/8HqSRhJVxn',
      'github': 'https://github.com/pollinations',
      'youtube': 'https://www.youtube.com/channel/UCk4yKnLnYfyUmCCbDzOZOug',
      'instagram': 'https://instagram.com/pollinations_ai',
      'twitter': 'https://twitter.com/pollinations_ai',
    }
)

==> pollinations.ai-0.1.4.tar.gz: pollinations.ai-0.1.4/setup.py <==
from setuptools import setup, find_packages
from pathlib import Path

path_absolute = Path(__file__).parent.absolute()

with open(f'{path_absolute}/pollinations/__init__.py', 'r') as file:
  for line in file.readlines():
    if line.startswith('__version__'):
      version = line.split('=')[1].strip()[1:-1]
      break

setup(
    name="pollinations.ai",
    version=version,
    description="pollinations.ai | Image Generation",
    long_description=Path(f"{path_absolute}/README.md").read_text(encoding="utf-8"),
    long_description_content_type="text/markdown",
    url="https://pollinations.ai/",
    author="pollinations.ai",
    author_email="hello@pollinations.ai",
    license="MIT",
    classifiers=[
      "License :: OSI Approved :: MIT License",
      'Development Status :: 1 - Planning',
      'Intended Audience :: Developers',
      'License :: OSI Approved :: MIT License',
      'Programming Language :: Python',
      'Topic :: Software Development :: Libraries',
      'Topic :: Software Development :: Libraries :: Python Modules',
      'Topic :: Utilities',
      'Typing :: Typed'
    ],
    packages=find_packages(exclude=("tests",)),
    include_package_data=True,
    entry_points={
        "console_scripts": [
            "pollinations=pollinations.__init__:main",
        ]
    },
    python_requires=">=3.7",    
    keywords=['pollinations', 'pollinations.ai', 'pollinations-ai', 'pollinations_ai'],
    project_urls={
      'Website': 'https://pollinations.ai/',
      'Discord': 'https://discord.gg/8HqSRhJVxn',
      'Github': 'https://github.com/pollinations',
      'YouTube': 'https://www.youtube.com/channel/UCk4yKnLnYfyUmCCbDzOZOug',
      'Instagram': 'https://instagram.com/pollinations_ai',
      'Twitter': 'https://twitter.com/pollinations_ai',
    }
)
